@@ -2,7 +2,7 @@ use strictures 1;
 
 package Mojito::Model::MetaCPAN;
 {
-  $Mojito::Model::MetaCPAN::VERSION = '0.17';
+  $Mojito::Model::MetaCPAN::VERSION = '0.18';
 }
 use Moo;
 use HTTP::Tiny;
@@ -33,10 +33,10 @@ has cache => (
     is      => 'rw',
     default => sub {
         CHI->new(
-#            driver => 'Memory',
+            driver => 'Memory',
             global => 1,
-            driver   => 'File',
-            root_dir => '/tmp/chi_cache',
+#            driver   => 'File',
+            root_dir => '/tmp/mojito/cache',
         );
     },
 );
@@ -55,39 +55,37 @@ has markdown => (
 
 =head1 Methods
 
-=head2 get_synopsis
+=head2 get_synopsis_from_metacpan
 
-Retrieve the pod for a given module (in markdown format). 
-Extract the SYNOPSIS and return it.
+    Args: (Str: main module path, ModuleName: main module)
+    Returns: (Array: ($pod_url_used, @synopsis_lines)
 
 =cut
 
-sub get_synopsis {
-    my ($self, $Module) = @_;
-    return if not $Module;
-
-    my $cache_key = "${Module}:SYNOPSIS";
-    my $synopsis  = $self->cache->get($cache_key);
-    if (not $synopsis) {
-        warn "GET $Module from CPAN" if $ENV{MOJITO_DEBUG};
-        $synopsis = $self->get_synopsis_from_metacpan($Module);
-        $self->cache->set($cache_key, $synopsis, '1 day');
-    }
-
-    return if not $synopsis;
-    return wantarray ? split "\n", $synopsis : $synopsis;
-}
-
 sub get_synopsis_from_metacpan {
-    my ($self, $Module) = @_;
+    my ($self, $main_module, $pod_url) = @_;
 
-    my $pod_url =
-      "http://api.metacpan.org/pod/${Module}?content-type=text/x-markdown";
-    my $response = $self->http_client->get($pod_url);
-    if (not $response->{success}) {
-        return $self->not_found_string;
+    my $pod_url_used = 'release';
+    # Use markdown format (easy to parse out SYNOPSIS)
+    my $format = '?content-type=text/x-markdown';
+    my $secondary_pod_url = "http://api.metacpan.org/pod/${main_module}${format}";
+    if (not $pod_url) {
+        $pod_url = $secondary_pod_url;
+        $pod_url_used = 'main_module';
     }
-    my $content        = $response->{content}; # if length $response->{content};
+    else {
+        $pod_url .= $format;
+    }
+    my $response = $self->http_client->get($pod_url);
+    if (not $response->{success} && ($pod_url_used = 'release')) {
+        warn "Could not find POD at $pod_url. Trying: $secondary_pod_url..";
+        $response = $self->http_client->get($secondary_pod_url);
+        if (not $response->{success}) {
+            warn "Could not find POD at $secondary_pod_url";
+            return $self->not_found_string;
+        }
+    }        
+    my $content = $response->{content}; # if length $response->{content};
     my @synopsis_lines = ();
     my $seen_synopsis = my $seen_synopsis_end = 0;
     my @content_lines = split '\n', $content;
@@ -146,19 +144,23 @@ sub get_description_from_metacpan {
 =cut
 
 sub get_synopsis_formatted {
-    my ($self, $Module, $format) = @_;
+    my ($self, $release, $format) = @_;
     $format ||= 'presentation';
-
+    
+     my $main_module_pod_url = my $main_module = $release->{distribution};
+     $main_module =~ s|-|::|g;
+     $main_module_pod_url =~ s|-|/|g;
+     $main_module_pod_url = "http://api.metacpan.org/pod/$release->{author}/$release->{name}/lib/${main_module_pod_url}.pm";
     # Just have the presentation format for starters.
     my $dispatch_table = {
         presentation => sub {
-
-            my @synopsis_lines = $self->get_synopsis_from_metacpan($Module);
+            my @synopsis_lines = $self->get_synopsis_from_metacpan($main_module, $main_module_pod_url);
             @synopsis_lines = $self->trim_lines(@synopsis_lines);
             if (not scalar @synopsis_lines) {
                 return $self->not_found_string;
             }
-            
+            my $abstract = '';
+            $abstract = "<section class='module_abstract'>$release->{abstract}</section>\n" if $release->{abstract};
             # Comment out lines that don't start with a comment
             # and are not indented (i.e. not code)
             # because we'd like the Synopsis to be runnable (in theory)
@@ -170,19 +172,19 @@ sub get_synopsis_formatted {
             my $synopsis = join "\n", @synopsis_lines;
 
             # pre wrapper for syntax highlight
-            $synopsis = "<pre class='prettyprint'>\n" . $synopsis . "</pre>\n";
-
-            $synopsis = "<h2 class='Module'><a href='http://metacpan.org/module/${Module}'>${Module}</a></h2>". $synopsis;
+            $synopsis = "${abstract}<pre class='prettyprint'>\n" . $synopsis . "</pre>\n";
+            $synopsis = "<h2 class='Module'><a href='https://metacpan.org/release/$release->{author}/$release->{name}'>$release->{distribution}</a></h2>" . $synopsis;
+            
             return $synopsis;
           }
     };
 
-    my $cache_key = "${Module}:SYNOPSIS:${format}";
+    my $cache_key = "$release->{name}:SYNOPSIS:${format}";
     my $synopsis  = $self->cache->get($cache_key);
     if (not $synopsis) {
-        warn "GET $Module SYNOPSIS from CPAN" if $ENV{MOJITO_DEBUG};
-        $synopsis = $dispatch_table->{$format}->($Module);
-        $self->cache->set($cache_key, $synopsis, '1 day');
+        warn "GET $main_module SYNOPSIS from CPAN" if $ENV{MOJITO_DEBUG};
+        $synopsis = $dispatch_table->{$format}->($main_module_pod_url);
+        $self->cache->set($cache_key, $synopsis, '3 days');
     }
     return $synopsis;
 }
@@ -204,13 +206,13 @@ sub trim_lines {
     # compact by removing the blank lines.
     shift @lines;
     return if not scalar @lines;
-    while ($lines[0] =~ m/^\s*?$/) {
+    while ($lines[0] && $lines[0] =~ m/^\s*?$/) {
         shift @lines;
     }
     return if not scalar @lines;
 
     # Do same for tail
-    while ($lines[-1] =~ m/^\s*?$/) {
+    while ($lines[-1] && $lines[-1] =~ m/^\s*?$/) {
         pop @lines;
     }
     return if not scalar @lines;
@@ -226,7 +228,7 @@ sub get_recent_releases_from_metacpan {
     my ($self, $how_many) = @_;
     $how_many ||= 10;
 
-    my @fields        = qw/author name distribution version maturity download_url/;
+    my @fields        = qw/author name distribution version maturity status abstract download_url/;
     my $fields_string = join ',', @fields;
     my $result        = $self->metacpan->release(
         search => {
@@ -305,13 +307,13 @@ sub get_recent_synopses {
 
     my $html;
     my $releases = $self->get_recent_releases($how_many);
-    # Avoid duplicatds
+    # Avoid duplicates
     my %have_seen = ();
     foreach my $release (@{$releases}) {
-        my $main_module = $release->{distribution}; 
+        my $main_module = $release->{distribution};
         $main_module =~ s/\-/::/g;
         next if $have_seen{$main_module};
-        my $synopsis = $self->get_synopsis_formatted($main_module, 'presentation');
+        my $synopsis = $self->get_synopsis_formatted($release, 'presentation');
         my $not_found_message = '';
         if ($synopsis eq $self->not_found_string) {
             $not_found_message = 'Synopsis not found for '; 
