@@ -1,11 +1,11 @@
 use strictures 1;
 package Mojito::Template;
 {
-  $Mojito::Template::VERSION = '0.17';
+  $Mojito::Template::VERSION = '0.18';
 }
 use Moo;
 use 5.010;
-use MooX::Types::MooseLike qw(:all);
+use MooX::Types::MooseLike::Base qw(:all);
 use Mojito::Model::Link;
 use Mojito::Collection::CRUD;
 use Mojito::Page::Publish;
@@ -133,7 +133,7 @@ $js_css
     <input id="mongo_id" name="mongo_id" type="hidden" form="editForm" value="" />
     <input id="wiki_language" name="wiki_language" type="hidden" form="editForm" value="" />
     <input id="page_title" name="page_title" type="hidden" form="editForm" value="" />
-    <textarea id="content"  name="content" rows=32 required="required"/></textarea>
+    <textarea id="content" name="content" rows="32" required="required"/></textarea>
     <input id="commit_message" name="commit_message" value="commit message" onclick="this.value == 'commit message' ? this.value = '' : true"/>
     <input id="submit_save" name="submit" type="submit" value="Save" style="font-size: 66.7%;" />
     <input id="submit_view" name="submit" type="submit" value="Done" style="font-size: 66.7%;" />
@@ -375,6 +375,7 @@ s/(<section\s+id="view_area"[^>]*>)<\/section>/$1${page_view}<\/section>/si;
     $output =~ s/<nav id="side">.*?<\/nav>//si;
 #    $output =~ s/<section id="recent_area".*?><\/section>//si;
     $output =~ s/<div id="wiki_language".*?>.*?<\/div>//si;
+    $output =~ s|(</header>)|<button id="toggle_view">Toggle View</button>\n$1|si;
 
     # Remove edit and new links
     $output =~ s/<nav id="edit_link".*?><\/nav>//sig;
