@@ -1,10 +1,10 @@
 use strictures 1;
 package Mojito::Template::Role::CSS;
 {
-  $Mojito::Template::Role::CSS::VERSION = '0.17';
+  $Mojito::Template::Role::CSS::VERSION = '0.18';
 }
 use Moo::Role;
-use MooX::Types::MooseLike qw(:all);
+use MooX::Types::MooseLike::Base qw(:all);
 
 =head1 Name
 
@@ -23,7 +23,7 @@ has css => (
 
 sub _build_css {
     [
-      'css/ui-lightness/jquery-ui-1.8.11.custom.css',
+      'css/ui-lightness/jquery-ui.custom.css',
       'syntax_highlight/prettify_mojito.css',
       'SHJS/sh_mojito.css',
       'css/mojito.css',
